import unittest

from checkov.terraform.checks.resource.azure.AzureInstancePassword import check
from checkov.terraform.models.enums import CheckResult


class TestAzureInstancePassword(unittest.TestCase):

    def test_failure(self):
        resource_conf = {'name': ['${var.prefix}-vm'], 'location': ['${azurerm_resource_group.main.location}'],
                         'resource_group_name': ['${azurerm_resource_group.main.name}'],
                         'network_interface_ids': [['${azurerm_network_interface.main.id}']],
                         'vm_size': ['Standard_DS1_v2'], 'storage_image_reference': [
                {'publisher': ['Canonical'], 'offer': ['UbuntuServer'], 'sku': ['16.04-LTS'], 'version': ['latest']}],
                         'storage_os_disk': [
                             {'name': ['myosdisk1'], 'caching': ['ReadWrite'], 'create_option': ['FromImage'],
                              'managed_disk_type': ['Standard_LRS']}], 'os_profile': [
                {'computer_name': ['hostname'], 'admin_username': ['testadmin'], 'admin_password': ['Password1234!']}],
                         'os_profile_linux_config': [{'disable_password_authentication': [False]}]
                         }

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {'name': ['${var.prefix}-vm'], 'location': ['${azurerm_resource_group.main.location}'],
                         'resource_group_name': ['${azurerm_resource_group.main.name}'],
                         'network_interface_ids': [['${azurerm_network_interface.main.id}']],
                         'vm_size': ['Standard_DS1_v2'], 'storage_image_reference': [
                {'publisher': ['Canonical'], 'offer': ['UbuntuServer'], 'sku': ['16.04-LTS'], 'version': ['latest']}],
                         'storage_os_disk': [
                             {'name': ['myosdisk1'], 'caching': ['ReadWrite'], 'create_option': ['FromImage'],
                              'managed_disk_type': ['Standard_LRS']}], 'os_profile': [
                {'computer_name': ['hostname'], 'admin_username': ['testadmin'], 'admin_password': ['Password1234!']}],
                         'os_profile_linux_config': [{'disable_password_authentication': [True]}]
                         }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.KMSRotation import check
from checkov.terraform.models.enums import CheckResult


class TestKMSRotation(unittest.TestCase):

    def test_success(self):
        resource_conf = {
            "description": "KMS key 1",
            "deletion_window_in_days": 10,
            "enable_key_rotation": True
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)

    def test_failure(self):
        resource_conf = {
            "description": "KMS key 1",
            "deletion_window_in_days": 10,
            "enable_key_rotation": False
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_failure_on_missing_property(self):
        resource_conf = {
            "description": "KMS key 1",
            "deletion_window_in_days": 10,
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)


if __name__ == '__main__':
    unittest.main()



import json

from colorama import init
from junit_xml import TestCase, TestSuite
from termcolor import colored

from checkov.terraform.models.enums import CheckResult

init(autoreset=True)


class Report:
    passed_checks = []
    failed_checks = []
    suppressed_checks = []
    parsing_errors = []

    def add_parsing_errors(self, files):
        for file in files:
            self.add_parsing_error(file)

    def add_parsing_error(self, file):
        if file:
            self.parsing_errors.append(file)

    def add_record(self, record):
        if record.check_result == CheckResult.SUCCESS:
            self.passed_checks.append(record.__dict__)
        if record.check_result == CheckResult.FAILURE:
            self.failed_checks.append(record.__dict__)
        if record.check_result == CheckResult.SUPPRESSED:
            self.suppressed_checks.append(record.__dict__)

    def get_summary(self):
        return {
            "passed": len(self.passed_checks),
            "failed": len(self.failed_checks),
            "suppressed": len(self.suppressed_checks),
            "parsing_errors": len(self.parsing_errors)
        }

    def get_json(self):
        return json.dumps(self.get_dict(), indent=4)

    def get_dict(self):
        return {
            "results": {
                "passed_checks": self.passed_checks,
                "failed_checks": self.failed_checks,
                "suppressed_checks": self.suppressed_checks,
                "parsing_errors": self.parsing_errors
            },
            "summary": self.get_summary()
        }

    def print_console(self):
        report_dict = self.get_dict()
        summary = report_dict["summary"]

        if self.parsing_errors:
            message = "\nPassed Checks: {}, Failed Checks: {}, Suppressed Checks: {}, Parsing Errors: {}\n".format(
                summary["passed"], summary["failed"], summary["suppressed"], summary["parsing_errors"])
        else:
            message = "\nPassed Checks: {}, Failed Checks: {}, Suppressed Checks: {}\n".format(
                summary["passed"], summary["failed"], summary["suppressed"])
        print(colored(message, "cyan"))

        for record in report_dict["results"]["passed_checks"]:
            self.print_record_console(record)
        for record in report_dict["results"]["failed_checks"]:
            self.print_record_console(record)

    @staticmethod
    def print_record_console(record):
        if record['check_result'] == CheckResult.SUCCESS:
            status = "Passed"
            status_color = "green"
        else:
            status = "Failed"
            status_color = "red"
        check_message = colored("Check: \"{}\"\n".format(record["check_name"]), "white")
        file_details = colored("{}:{}\n".format(record["file_path"], record["file_line_range"]), "magenta")
        status_message = colored("\t {} for resource: {} ".format(status, record["resource"]), status_color)
        message = check_message + file_details + status_message
        print(message)

    def print_junit_xml(self):
        ts = self.get_test_suites()
        print(TestSuite.to_xml_string(ts))

    def get_test_suites(self):
        test_cases = {}
        test_suites = []
        records = self.passed_checks + self.failed_checks
        for record in records:
            check_name = record['check_name']
            if check_name not in test_cases:
                test_cases[check_name] = []

            test_name = "{} {}".format(check_name, record['resource'])
            test_case = TestCase(name=test_name, file=record['file_path'], classname=record["check_class"])
            if record['check_result'] == CheckResult.FAILURE:
                test_case.add_failure_info(
                    "Resource \"{}\" failed in check \"{}\"".format(record['resource'], check_name))
            test_cases[check_name].append(test_case)
        for key in test_cases.keys():
            test_suites.append(
                TestSuite(name=key, test_cases=test_cases[key], package=test_cases[key][0].classname))
        return test_suites

    def print_json(self):
        print(self.get_json())



import unittest

from checkov.terraform.checks.resource.aws.ElasticsearchEncryption import check
from checkov.terraform.models.enums import CheckResult


class TestElasticsearchEncryption(unittest.TestCase):

    def test_failure(self):
        resource_conf = {'count': ['${var.enabled ? 1 : 0}'], 'domain_name': ['${module.label.id}'],
                         'elasticsearch_version': ['${var.elasticsearch_version}'],
                         'advanced_options': ['${var.advanced_options}'], 'ebs_options': [
                {'ebs_enabled': ['${var.ebs_volume_size > 0 ? True : False}'],
                 'volume_size': ['${var.ebs_volume_size}'], 'volume_type': ['${var.ebs_volume_type}'],
                 'iops': ['${var.ebs_iops}']}],
                         'encrypt_at_rest': [{'enabled': [False], 'kms_key_id': ['${var.encrypt_at_rest_kms_key_id}']}],
                         'cluster_config': [{'instance_count': [3], 'instance_type': ['${var.instance_type}'],
                                             'dedicated_master_enabled': ['${var.dedicated_master_enabled}'],
                                             'dedicated_master_count': ['${var.dedicated_master_count}'],
                                             'dedicated_master_type': ['${var.dedicated_master_type}'],
                                             'zone_awareness_enabled': ['${var.zone_awareness_enabled}'],
                                             'zone_awareness_config': [
                                                 {'availability_zone_count': ['${var.availability_zone_count}']}]}],
                         'node_to_node_encryption': [{'enabled': [False]}], 'vpc_options': [
                {'security_group_ids': [['${join("",aws_security_group.default.*.id)}']],
                 'subnet_ids': ['${var.subnet_ids}']}], 'snapshot_options': [
                {'automated_snapshot_start_hour': ['${var.automated_snapshot_start_hour}']}],
                         'log_publishing_options': [
                             {'enabled': ['${var.log_publishing_index_enabled}'], 'log_type': ['INDEX_SLOW_LOGS'],
                              'cloudwatch_log_group_arn': ['${var.log_publishing_index_cloudwatch_log_group_arn}']},
                             {'enabled': ['${var.log_publishing_search_enabled}'], 'log_type': ['SEARCH_SLOW_LOGS'],
                              'cloudwatch_log_group_arn': ['${var.log_publishing_search_cloudwatch_log_group_arn}']},
                             {'enabled': ['${var.log_publishing_application_enabled}'],
                              'log_type': ['ES_APPLICATION_LOGS'], 'cloudwatch_log_group_arn': [
                                 '${var.log_publishing_application_cloudwatch_log_group_arn}']}],
                         'tags': ['${module.label.tags}'], 'depends_on': [['${aws_iam_service_linked_role.default}']]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf ={'count': ['${var.enabled ? 1 : 0}'], 'domain_name': ['${module.label.id}'],
                        'elasticsearch_version': ['${var.elasticsearch_version}'],
                        'advanced_options': ['${var.advanced_options}'], 'ebs_options': [
                {'ebs_enabled': ['${var.ebs_volume_size > 0 ? True : False}'],
                 'volume_size': ['${var.ebs_volume_size}'], 'volume_type': ['${var.ebs_volume_type}'],
                 'iops': ['${var.ebs_iops}']}],
                        'encrypt_at_rest': [{'enabled': [True], 'kms_key_id': ['${var.encrypt_at_rest_kms_key_id}']}],
                        'cluster_config': [{'instance_count': [3], 'instance_type': ['${var.instance_type}'],
                                            'dedicated_master_enabled': ['${var.dedicated_master_enabled}'],
                                            'dedicated_master_count': ['${var.dedicated_master_count}'],
                                            'dedicated_master_type': ['${var.dedicated_master_type}'],
                                            'zone_awareness_enabled': ['${var.zone_awareness_enabled}'],
                                            'zone_awareness_config': [
                                                {'availability_zone_count': ['${var.availability_zone_count}']}]}],
                        'node_to_node_encryption': [{'enabled': [True]}], 'vpc_options': [
                {'security_group_ids': [['${join("",aws_security_group.default.*.id)}']],
                 'subnet_ids': ['${var.subnet_ids}']}], 'snapshot_options': [
                {'automated_snapshot_start_hour': ['${var.automated_snapshot_start_hour}']}],
                        'log_publishing_options': [
                            {'enabled': ['${var.log_publishing_index_enabled}'], 'log_type': ['INDEX_SLOW_LOGS'],
                             'cloudwatch_log_group_arn': ['${var.log_publishing_index_cloudwatch_log_group_arn}']},
                            {'enabled': ['${var.log_publishing_search_enabled}'], 'log_type': ['SEARCH_SLOW_LOGS'],
                             'cloudwatch_log_group_arn': ['${var.log_publishing_search_cloudwatch_log_group_arn}']},
                            {'enabled': ['${var.log_publishing_application_enabled}'],
                             'log_type': ['ES_APPLICATION_LOGS'], 'cloudwatch_log_group_arn': [
                                '${var.log_publishing_application_cloudwatch_log_group_arn}']}],
                        'tags': ['${module.label.tags}'], 'depends_on': [['${aws_iam_service_linked_role.default}']]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.PasswordPolicySymbol import check
from checkov.terraform.models.enums import CheckResult


class TestPasswordPolicySymbol(unittest.TestCase):

    def test_success(self):
        resource_conf = {
            "minimum_password_length": 8,
            "require_lowercase_characters": True,
            "require_numbers": True,
            "require_uppercase_characters": True,
            "require_symbols": True,
            "allow_users_to_change_password": True,
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)

    def test_failure(self):
        resource_conf = {
            "minimum_password_length": 8,
            "require_lowercase_characters": False,
            "require_numbers": True,
            "require_uppercase_characters": True,
            "require_symbols": False,
            "allow_users_to_change_password": True,
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_failure_on_missing_property(self):
        resource_conf = {
            "minimum_password_length": 8,
            "require_lowercase_characters": True,
            "require_numbers": True,
            "allow_users_to_change_password": True,
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.AdminPolicyDocument import check
from checkov.terraform.models.enums import CheckResult


class TestAdminPolicyDocument(unittest.TestCase):

    def test_success(self):
        resource_conf = {
            "statement": {
                "actions": ["Describe*"],
                "resources": ["arn:aws:s3:::my_corporate_bucket/*"]
            }
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)

    def test_failure(self):
        resource_conf = {
            "statement": {
                "actions": ["*"],
                "resources": ["*"]
            }
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)



if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.LaunchConfigurationEBSEncryption import check
from checkov.terraform.models.enums import CheckResult


class TestS3Encryption(unittest.TestCase):

    def test_failure(self):
        resource_conf =  {'image_id': ['ami-123'], 'instance_type': ['t2.micro'], 'root_block_device': [{'encrypted': [False]}]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf =  {'image_id': ['ami-123'], 'instance_type': ['t2.micro'], 'root_block_device': [{'encrypted': [True]}]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.gcp.GoogleComputeFirewallUnrestrictedIngress3389 import check, PORT
from checkov.terraform.models.enums import CheckResult


class TestGoogleComputeFirewallUnrestrictedIngress22(unittest.TestCase):

    def test_failure(self):
        resource_conf = {'name': ['${var.name}-${var.region}-mesos-ssh'],
                         'network': ['${google_compute_network.mesos-global-net.name}'],
                         'allow': [{'protocol': ['tcp'], 'ports': [[PORT]]}], 'target_tags': [['ssh']],
                         'source_ranges': [['0.0.0.0/0']]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {'name': ['${var.name}-${var.region}-mesos-ssh'],
                         'network': ['${google_compute_network.mesos-global-net.name}'],
                         'allow': [{'protocol': ['tcp'], 'ports': [[
                             PORT]]}], 'target_tags': [['ssh']], 'source_ranges': [['172.1.2.3/32']]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.gcp.GoogleComputeMinTLSVersion import check
from checkov.terraform.models.enums import CheckResult


class TestGoogleComputeMinTLSVersion(unittest.TestCase):

    def test_failure(self):
        resource_conf =  {'name': ['nonprod-ssl-policy'], 'profile': ['MODERN']
                          }

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {'name': ['nonprod-ssl-policy'], 'profile': ['MODERN'], 'min_tls_version': ['TLS_1_2']}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.azure.AzureManagedDiscEncryption import check
from checkov.terraform.models.enums import CheckResult


class TestAzureManagedDiscEncryption(unittest.TestCase):

    def test_failure(self):
        resource_conf =  {'encryption_settings': [{'enabled': [False]}]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        def test_failure(self):
            resource_conf =  {'encryption_settings': [{'enabled': [True]}]}
            scan_result = check.scan_resource_conf(conf=resource_conf)
            self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.SagemakerEncryption import check
from checkov.terraform.models.enums import CheckResult


class TestSagemakerEncryption(unittest.TestCase):

    def test_failure(self):
        resource_conf = {'name': ['my-notebook-instance'], 'role_arn': ['${aws_iam_role.role.arn}'],
                         'instance_type': ['ml.t2.medium']}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {'name': ['my-notebook-instance'], 'role_arn': ['${aws_iam_role.role.arn}'],
                         'instance_type': ['ml.t2.medium'], 'kms_key_id': ['foo']}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)

if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.SecurityGroupRuleDescription import check
from checkov.terraform.models.enums import CheckResult


class TestSecurityGroupRuleDescription(unittest.TestCase):

    def test_failure(self):
        resource_conf = {
            "name": "allow_ssh",
            "vpc_id": "${aws_vpc.main.id}",
            "ingress": {
                # TLS (change to whatever ports you need),
                "from_port": 22,
                "to_port": 22,
                "protocol": "-1",
                "cidr_blocks": ['0.0.0.0/0'],
            },

            "egress": {
                "from_port": 0,
                "to_port": 0,
                "protocol": "-1",
                "cidr_blocks": ["0.0.0.0/0"],
                "prefix_list_ids": ["pl-12c4e678"],
            }
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {
            "name": "allow_ssh",
            "description": "Allow SSH inbound traffic",
            "vpc_id": "${aws_vpc.main.id}",
            "ingress": {
                # TLS (change to whatever ports you need),
                "from_port": 443,
                "to_port": 443,
                "protocol": "-1",
                "cidr_blocks": ['0.0.0.0/0'],
            },

            "egress": {
                "from_port": 0,
                "to_port": 0,
                "protocol": "-1",
                "cidr_blocks": ["0.0.0.0/0"],
                "prefix_list_ids": ["pl-12c4e678"],
            }
        }
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import os
import unittest

from checkov.terraform.runner import Runner

dir_path = os.path.dirname(os.path.realpath(__file__))


class TestRunner(unittest.TestCase):

    def test_runner(self):
        runner = Runner()
        report = runner.run(root_folder=dir_path)
        report_json = report.get_json()
        self.assertTrue(isinstance(report_json, str))
        self.assertIsNotNone(report_json)
        self.assertIsNotNone(report.get_test_suites())
        summary = report.get_summary()
        self.assertGreaterEqual(summary['passed'], 1)
        self.assertGreaterEqual(summary['failed'], 1)
        self.assertEqual(summary["parsing_errors"], 0)
        report.print_json()
        report.print_console()
        report.print_junit_xml()


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.gcp.GoogleStorageBucketEncryption import check
from checkov.terraform.models.enums import CheckResult


class TestGoogleStorageBucketEncryption(unittest.TestCase):

    def test_failure(self):
        resource_conf = {'name': ['my-bucket'],
                         'location': ['EU']
                         }

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {'name': ['my-bucket'],
                         'location': ['EU'],
                         'encryption': [{'default_kms_key_name': ['foo']}]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.ALBListenerHTTPS import check
from checkov.terraform.models.enums import CheckResult


class TestALBListenerHTTPS(unittest.TestCase):

    def test_success_redirect(self):
        resource_conf = {'load_balancer_arn': ['${aws_lb.front_end.arn}'], 'port': ['80'], 'protocol': ['HTTP'],
                         'default_action': [{'type': ['redirect'], 'redirect': [
                             {'port': ['443'], 'protocol': ['HTTPS'], 'status_code': ['HTTP_301']}]}]}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)

    def test_success(self):
        resource_conf = {'load_balancer_arn': ['${aws_lb.front_end.arn}'], 'port': ['443'], 'protocol': ['HTTPS']}

        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)

    def test_failure(self):
        resource_conf = {'load_balancer_arn': ['${aws_lb.front_end.arn}'], 'port': ['80'], 'protocol': ['HTTP']}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)


if __name__ == '__main__':
    unittest.main()



import unittest

from checkov.terraform.checks.resource.aws.SQSQueueEncryption import check
from checkov.terraform.models.enums import CheckResult


class TestS3Encryption(unittest.TestCase):

    def test_failure(self):
        resource_conf = {'name': ['terraform-example-queue']}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.FAILURE, scan_result)

    def test_success(self):
        resource_conf = {'name': ['terraform-example-queue'], 'kms_master_key_id': ['alias/aws/sqs'],
                         'kms_data_key_reuse_period_seconds': [300]}
        scan_result = check.scan_resource_conf(conf=resource_conf)
        self.assertEqual(CheckResult.SUCCESS, scan_result)


if __name__ == '__main__':
    unittest.main()
